Class: Async::Ollama::Pull
- Inherits:
-
Object
- Object
- Async::Ollama::Pull
- Defined in:
- lib/async/ollama/pull.rb
Overview
Represents the response from pulling models from the Ollama API.
Represents the response from pulling models from the Ollama API.