Class: Async::Ollama::Chat

Inherits:
Object
  • Object
show all
Defined in:
lib/async/ollama/chat.rb

Overview

Represents a chat response from the Ollama API, including message content, model, and timing information.

Instance Method Summary collapse

Instance Method Details

#errorObject



19
20
21
# File 'lib/async/ollama/chat.rb', line 19

def error
	self.value[:error]
end

#eval_countInteger | nil

Returns The number of tokens in the response.

Returns:

  • (Integer | nil)

    The number of tokens in the response.



56
57
58
# File 'lib/async/ollama/chat.rb', line 56

def eval_count
	self.value[:eval_count]
end

#eval_durationInteger | nil

Returns The time spent generating the response, in nanoseconds.

Returns:

  • (Integer | nil)

    The time spent generating the response, in nanoseconds.



61
62
63
# File 'lib/async/ollama/chat.rb', line 61

def eval_duration
	self.value[:eval_duration]
end

#load_durationInteger | nil

Returns The time spent loading the model, in nanoseconds.

Returns:

  • (Integer | nil)

    The time spent loading the model, in nanoseconds.



41
42
43
# File 'lib/async/ollama/chat.rb', line 41

def load_duration
	self.value[:load_duration]
end

#messageObject



14
15
16
# File 'lib/async/ollama/chat.rb', line 14

def message
	self.value[:message]
end

#modelObject



31
32
33
# File 'lib/async/ollama/chat.rb', line 31

def model
	self.value[:model]
end

#prompt_eval_countInteger | nil

Returns The number of tokens in the prompt (the token count).

Returns:

  • (Integer | nil)

    The number of tokens in the prompt (the token count).



46
47
48
# File 'lib/async/ollama/chat.rb', line 46

def prompt_eval_count
	self.value[:prompt_eval_count]
end

#prompt_eval_durationInteger | nil

Returns The time spent evaluating the prompt, in nanoseconds.

Returns:

  • (Integer | nil)

    The time spent evaluating the prompt, in nanoseconds.



51
52
53
# File 'lib/async/ollama/chat.rb', line 51

def prompt_eval_duration
	self.value[:prompt_eval_duration]
end

#token_countInteger

Returns The sum of prompt and response token counts.

Returns:

  • (Integer)

    The sum of prompt and response token counts.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/async/ollama/chat.rb', line 66

def token_count
	count = 0
	
	if prompt_eval_count = self.prompt_eval_count
		count += prompt_eval_count
	end
	
	if eval_count = self.eval_count
		count += eval_count
	end
	
	return count
end

#tool_callsObject



24
25
26
27
28
# File 'lib/async/ollama/chat.rb', line 24

def tool_calls
	if message = self.message
		message[:tool_calls]
	end
end

#total_durationInteger | nil

Returns The time spent generating the response, in nanoseconds.

Returns:

  • (Integer | nil)

    The time spent generating the response, in nanoseconds.



36
37
38
# File 'lib/async/ollama/chat.rb', line 36

def total_duration
	self.value[:total_duration]
end